=== modified file 'mojo/__init__.py'
--- mojo/__init__.py	2015-04-17 08:49:15 +0000
+++ mojo/__init__.py	2015-04-19 23:33:17 +0000
@@ -261,10 +261,12 @@
             # automatically
             auto_secrets = False 
         for phase_name in self.phases:
-            if phase_name.name == "deploy":
-                phase_name.run(project, workspace, series, stage, auto_secrets)
+            if phase_name.name in ["deploy", "build", "script", "verify"]:
+                phase_name.run(project, workspace, series, stage,
+                               auto_secrets=auto_secrets)
             elif phase_name.name == "collect":
-                phase_name.run(project, workspace, series, stage, auto_repo)
+                phase_name.run(project, workspace, series, stage,
+                               auto_repo=auto_repo)
             else:
                 phase_name.run(project, workspace, series, stage)
 

=== modified file 'mojo/phase.py'
--- mojo/phase.py	2015-04-17 08:49:15 +0000
+++ mojo/phase.py	2015-04-19 23:33:17 +0000
@@ -231,10 +231,11 @@
     name = "script"
 
     def run(self, project, workspace, series, stage=None, lxc=False,
-            network=True):
-        # Run secrets phase automatically first
-        secrets = mojo.phase.build('secrets', **{'auto_secrets': True})
-        secrets.run(project, workspace, series, stage)
+            network=True, auto_secrets=True):
+        if auto_secrets:
+            # Run secrets phase automatically first
+            secrets = mojo.phase.build('secrets', **{'auto_secrets': True})
+            secrets.run(project, workspace, series, stage)
         logging.debug("### Running phase {} with options {}".format(self.name,
                       self.options))
         logging.info("Running script {}".format(self.config_base))
@@ -277,14 +278,12 @@
     """
     name = "build"
 
-    def run(self, project, workspace, series, stage):
-        # Run secrets phase automatically first
-        secrets = mojo.phase.build('secrets', **{'auto_secrets': True})
-        secrets.run(project, workspace, series, stage)
+    def run(self, project, workspace, series, stage, auto_secrets=True):
         "Run a build script"
         # XXX: Remove network access during build phase
         super(BuildPhase, self).run(project, workspace, series, stage,
-                                    lxc=True, network=False)
+                                    lxc=True, network=False,
+                                    auto_secrets=auto_secrets)
 
 
 class CharmRepoPhase(Phase):
@@ -452,8 +451,9 @@
     """
     name = "verify"
 
-    def run(self, project, workspace, series, stage):
-        super(VerifyPhase, self).run(project, workspace, series, stage)
+    def run(self, project, workspace, series, stage, auto_secrets=True):
+        super(VerifyPhase, self).run(project, workspace, series, stage,
+                                     auto_secrets=auto_secrets)
 
 
 # ========================================

